==> tmaid-2.1.4.tar.gz: tmaid-2.1.4/src/edit.h <==
/*
    Text maid
    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __EDIT_H__
#define __EDIT_H__


#include "tmaid.h"


/*	Cobt@߂
	start,Cobt@
	  off,݂yW
	    y,yW
	  RET,Cobt@													*/
LINEBUF *get_line_buf(LINEBUF **start,gint *off,gint y);


/*	擾
	start,Cobt@
	  off,݂yW
	    y,s
	  tab,^u
	  RET,																*/
gint get_width(LINEBUF **start,gint *off,gint y,gint tab);


/*	ő包擾
	ptw,TXTEChE
	RET,																*/
gint get_width_max(TEXTWND *ptw);


/*	Lbg̃ACgꂽxW߂
	start,Cobt@
	  off,݂yW
	    x,xW
	    y,yW
	  tab,^u
	align,TRUE:EɊ񂹂,FALSE:Ɋ񂹂
	  RET,W																*/
gint get_align_pos(LINEBUF **start,gint *off,
										gint x,gint y,gint tab,gboolean align);


/*	ʏ̍W烉Cobt@̃AhX߂
	start,Cobt@
	  off,݂yW
	    x,xW
	    y,yW
	  tab,^u
	align,TRUE:EɊ񂹂,FALSE:Ɋ񂹂
	  RET,AhX															*/
gint get_data_pos(LINEBUF **start,gint *off,gint x,gint y,
													gint tab,gboolean align);


/*	Cobt@̃AhXʏ̍W߂
	start,Cobt@
	  off,݂yW
	    x,xW
	    y,yW
	  tab,^u
	  RET,W																*/
gint get_screen_pos(LINEBUF **start,gint *off,gint x,gint y,gint tab);


/*	̕
	  text,
	length,
	   RET,																*/
guint get_char_type(gchar *text,gint length);


/*	؂߂
	start,Cobt@
	  off,݂yW
	    x,xW
	    y,yW
	  tab,^u
	 move,TRUE:EɈړ,FALSE:Ɉړ
	  RET,W																*/
gint get_move_pos(LINEBUF **start,gint *off,gint x,gint y,
													gint tab,gboolean move);


/*	w͈͂̃oCg߂
	  start,Cobt@
	    off,݂yW
	start_p,I͈
	  end_p,I͈
	    tab,^u
	    RET,oCg														*/
gint get_sel_byte(LINEBUF **start,gint *off,
								GdkPoint *start_p,GdkPoint *end_p,gint tab);


/*	w͈͂ɃRs[
	  start,Cobt@
	    off,݂yW
	start_p,I͈
	  end_p,I͈
	    tab,^u
	   text,															*/
void cpy_sel_mem(LINEBUF **start,gint *off,
					GdkPoint *start_p,GdkPoint *end_p,gint tab,gchar *text);


/*	̓e\t
	 start,Cobt@
	   off,݂yW
	   put,\tW
	   new,VW
	   tab,^u
	  text,
	length,oCg
	margin,E}[W(0Ȃΐ܂ԂȂ)
	   RET,}ꂽs													*/
gint put_mem(LINEBUF **start,gint *off,GdkPoint *put,GdkPoint *new,
								gint tab,gchar *text,gint length,gint margin);


/*	w͈͂폜
	  start,Cobt@
	    off,݂yW
	start_p,I͈
	  end_p,I͈
	    tab,^u
	 margin,E}[W(0Ȃΐ܂ԂȂ)
	    RET,폜ꂽs													*/
gint del_sel_mem(LINEBUF **start,gint *off,
					GdkPoint *start_p,GdkPoint *end_p,gint tab,gint margin);


#endif

==> tmaid-2.1.18.tar.gz: tmaid-2.1.18/src/edit.h <==
/*
    Text maid
    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __EDIT_H__
#define __EDIT_H__


#include "tmaid.h"


/*	Cobt@߂
	start,Cobt@
	  off,݂yW
	    y,yW
	  RET,Cobt@													*/
LINEBUF *get_line_buf(LINEBUF **start,gint *off,gint y);


/*	擾
	ptw,TXTEChE
	  y,s
	RET,																*/
gint get_width(TEXTWND *ptw,gint y);


/*	ő包擾
	ptw,TXTEChE
	RET,																*/
gint get_width_max(TEXTWND *ptw);


/*	Lbg̃ACgꂽxW߂
	  ptw,TXTEChE
	    x,xW
	    y,yW
	align,TRUE:EɊ񂹂,FALSE:Ɋ񂹂
	  RET,W																*/
gint get_align_pos(TEXTWND *ptw,gint x,gint y,gboolean align);


/*	ʏ̍W烉Cobt@̃AhX߂
	  ptw,TXTEChE
	    x,xW
	    y,yW
	align,TRUE:EɊ񂹂,FALSE:Ɋ񂹂
	  RET,AhX															*/
gint get_data_pos(TEXTWND *ptw,gint x,gint y,gboolean align);


/*	Cobt@̃AhXʏ̍W߂
	ptw,TXTEChE
	  x,xW
	  y,yW
	RET,W																*/
gint get_screen_pos(TEXTWND *ptw,gint x,gint y);


/*	̕
	  text,
	length,
	   RET,																*/
guint get_char_type(gchar *text,gint length);


/*	؂߂
	 ptw,TXTEChE
	   x,xW
	   y,yW
	move,TRUE:EɈړ,FALSE:Ɉړ
	 RET,W																*/
gint get_move_pos(TEXTWND *ptw,gint x,gint y,gboolean move);


/*	w͈͂̃oCg߂
	     ptw,TXTEChE
	 start_p,I͈
	   end_p,I͈
	     RET,oCg														*/
gint get_sel_bytes(TEXTWND *ptw,GdkPoint *start_p,GdkPoint *end_p);


/*	w͈͂ɃRs[
	    ptw,TXTEChE
	start_p,I͈
	  end_p,I͈
	   text,															*/
void cpy_sel_mem(TEXTWND *ptw,GdkPoint *start_p,GdkPoint *end_p,gchar *text);


/*	̓e\t
	   ptw,TXTEChE
	   put,\tW
	   new,VW
	  text,
	length,oCg
	   RET,}ꂽs													*/
gint put_mem(TEXTWND *ptw,GdkPoint *put,GdkPoint *new,gchar *text,gint length);


/*	w͈͂폜
	    ptw,TXTEChE
	start_p,I͈
	  end_p,I͈
	    RET,폜ꂽs													*/
gint del_sel_mem(TEXTWND *ptw,GdkPoint *start_p,GdkPoint *end_p);


#endif
